changeset 1461:ad5303b6d35a

Switch USE_UNSTABLE to USE_ALT and download.sh's UNSTABLE= to ALT= so naming is consistent with the alt- prefixes on packages and patches.
author Rob Landley <rob@landley.net>
date Thu, 20 Oct 2011 02:07:10 -0500
parents 876d4849afa1
children 61b784a003c3
files config download.sh more/bisectinate.sh more/cronjob.sh more/migrate-kernel.sh sources/README sources/download_functions.sh sources/functions.sh
diffstat 8 files changed, 37 insertions(+), 35 deletions(-) [+]
line wrap: on
line diff
--- a/config	Thu Oct 20 02:05:11 2011 -0500
+++ b/config	Thu Oct 20 02:07:10 2011 -0500
@@ -81,10 +81,12 @@
 
 # export NO_SANITIZE_ENVIRONMENT=1
 
-# Try development versions of these packages.  (Know what you're doing if
-# you select these, it's quite possible the result won't work.)
+# Use alternative versions of these packages, using the ALT= URL in download.sh
+# to fetch an alt-$PACKAGE-0 tarball.  (This is mostly used to test unstable
+# versions of packages out of source control systems.  There are no checksums
+# or versioning performed on alt packages, it's all done by hand.)
 
-# export USE_UNSTABLE=uClibc,busybox,linux,binutils,make,gcc-core,gcc-g++
+# export USE_ALT=uClibc,busybox,linux,binutils,make,gcc-core,gcc-g++
 
 # Debugging option to leave source in build/temp-$ARCH after build.
 
--- a/more/bisectinate.sh	Thu Oct 20 02:05:11 2011 -0500
+++ b/more/bisectinate.sh	Thu Oct 20 02:07:10 2011 -0500
@@ -95,7 +95,7 @@
 
   # Try the build
 
-  EXTRACT_ALL=1 ALLOW_PATCH_FAILURE=1 USE_UNSTABLE="$PKG" \
+  EXTRACT_ALL=1 ALLOW_PATCH_FAILURE=1 USE_ALT="$PKG" \
     ./build.sh "$ARCH" 2>&1 | tee -a "$BUILD"/logs/bisectinate-"$ARCH".txt
 
   # Did it work?
--- a/more/cronjob.sh	Thu Oct 20 02:05:11 2011 -0500
+++ b/more/cronjob.sh	Thu Oct 20 02:07:10 2011 -0500
@@ -41,17 +41,17 @@
 
 build_snapshot()
 {
-  if [ -z "$USE_UNSTABLE" ]
+  if [ -z "$USE_ALT" ]
   then
     SNAPNAME=base
   else
-    pull_repo $USE_UNSTABLE
-    SNAPNAME=$USE_UNSTABLE
+    pull_repo $USE_ALT
+    SNAPNAME=$USE_ALT
   fi
 
   echo === Building snapshot $SNAPNAME
 
-  [ "$USE_UNSTABLE" == linux ] &&
+  [ "$USE_ALT" == linux ] &&
     more/for-each-arch.sh 'more/migrate-kernel.sh $TARGET'
 
   # Update manifest
@@ -94,6 +94,6 @@
   PATH="$QPATH:$PATH" more/for-each-target.sh \
     'more/smoketest.sh $TARGET | tee snapshots/$SNAPSHOT_DATE/base/logs/newqemu-smoketest-$TARGET.txt'
 
-#USE_UNSTABLE=linux build_snapshot
-#USE_UNSTABLE=uClibc build_snapshot
-#USE_UNSTABLE=busybox build_snapshot
+#USE_ALT=linux build_snapshot
+#USE_ALT=uClibc build_snapshot
+#USE_ALT=busybox build_snapshot
--- a/sources/README	Thu Oct 20 02:05:11 2011 -0500
+++ b/sources/README	Thu Oct 20 02:07:10 2011 -0500
@@ -31,7 +31,7 @@
 
   patches: Patches applied to the packages listed in download.sh by "setupfor".
            Each package has "$PACKAGE-*.patch" applied in alphabetical order,
-           or "alt-$PACKAGE-*.patch" for USE_UNSTABLE versions.
+           or "alt-$PACKAGE-*.patch" for USE_ALT versions.
 
   targets: Configuration for each target platform, parsed by load_target()
            and getconfig() in functions.sh.  Each entry is a target name,
@@ -41,11 +41,11 @@
       settings: Environment variables needed by the build.
 
       miniconfig-linux: linux kernel .config compressed by toys/miniconfig.sh
-                        (If miniconfig-alt-linux exists, USE_UNSTABLE=linux
+                        (If miniconfig-alt-linux exists, USE_ALT=linux
                          will use that instead.)
 
       miniconfig-uClibc: uClibc .config compressed by toys/miniconfig.sh
-                         (If miniconfig-alt-uClibc exists, USE_UNSTABLE=uClibc
+                         (If miniconfig-alt-uClibc exists, USE_ALT=uClibc
                           will use that instead.)
 
   root-filesystem: Files to be copied verbatim into the target filesystem.
--- a/sources/download_functions.sh	Thu Oct 20 02:05:11 2011 -0500
+++ b/sources/download_functions.sh	Thu Oct 20 02:07:10 2011 -0500
@@ -57,10 +57,10 @@
 {
   mkdir -p "$SRCTREE" || dienow
 
-  # Figure out whether we're using an unstable package.
+  # Figure out whether we're using an alternative version of a package.
 
   PACKAGE="$1"
-  is_in_list "$PACKAGE" $USE_UNSTABLE && PACKAGE=alt-"$PACKAGE"
+  is_in_list "$PACKAGE" $USE_ALT && PACKAGE=alt-"$PACKAGE"
 
   # Announce to the world that we're cracking open a new package
 
@@ -197,8 +197,8 @@
 
   echo -ne "checking $FILENAME\r"
 
-  # Update timestamps on both stable and unstable tarballs (if any)
-  # so cleanup_oldfiles doesn't delete stable when we're building unstable
+  # Update timestamps on both stable and alternative tarballs (if any)
+  # so cleanup_oldfiles doesn't delete stable when we're building alt
   # or vice versa
 
   touch -c "$SRCDIR"/{"$FILENAME","$ALTFILENAME"} 2>/dev/null
@@ -206,10 +206,10 @@
   # Give package name, minus file's version number and archive extension.
   BASENAME="$(noversion "$FILENAME")"
 
-  # If unstable version selected, try from listed location, and fall back
-  # to PREFERRED_MIRROR.  Do not try normal mirror locations for unstable.
+  # If alternative version selected, try from listed location, and fall back
+  # to PREFERRED_MIRROR.  Do not try normal mirror locations for alt packages.
 
-  if is_in_list "$BASENAME" $USE_UNSTABLE
+  if is_in_list "$BASENAME" $USE_ALT
   then
     # If extracted source directory exists, don't download alt-tarball.
     if [ -e "$SRCTREE/alt-$BASENAME" ]
@@ -224,7 +224,7 @@
 
     ([ ! -z "$PREFERRED_MIRROR" ] &&
       download_from "$PREFERRED_MIRROR/$ALTFILENAME") ||
-      download_from "$UNSTABLE"
+      download_from "$ALT"
     return $?
   fi
 
--- a/sources/functions.sh	Thu Oct 20 02:05:11 2011 -0500
+++ b/sources/functions.sh	Thu Oct 20 02:07:10 2011 -0500
@@ -104,7 +104,7 @@
 
 getconfig()
 {
-  for i in $(is_in_list $1 $USE_UNSTABLE && echo {$ARCH_NAME,$ARCH}/miniconfig-alt-$1) \
+  for i in $(is_in_list $1 $USE_ALT && echo {$ARCH_NAME,$ARCH}/miniconfig-alt-$1) \
     {$ARCH_NAME,$ARCH}/miniconfig-$1
   do
     [ -f "$CONFIG_DIR/$i" ] && cat "$CONFIG_DIR/$i" && return
@@ -248,7 +248,7 @@
 
 identify_release()
 {
-  if is_in_list "$1" $USE_UNSTABLE
+  if is_in_list "$1" $USE_ALT
   then
     for i in "b" ""
     do
@@ -266,7 +266,7 @@
       fi
     done
 
-    # Need to extract unstable packages to determine source control version.
+    # Need to extract alt packages to determine source control version.
 
     extract_package "$1" >&2
     DIR="${BUILD}/packages/alt-$1"
--- a/download.sh	Thu Oct 20 02:05:11 2011 -0500
+++ b/download.sh	Thu Oct 20 02:07:10 2011 -0500
@@ -23,33 +23,33 @@
 
 URL=http://www.kernel.org/pub/linux/kernel/v3.0/linux-3.0.tar.bz2 \
 SHA1=45b64bffc860f70ab7956da4493c488010714650 \
-UNSTABLE=http://kernel.org/pub/linux/kernel/v3.0/testing/linux-3.0-rc1.tar.bz2 \
+ALT=http://kernel.org/pub/linux/kernel/v3.0/testing/linux-3.0-rc1.tar.bz2 \
 maybe_fork "download || dienow"
 
 URL=http://uclibc.org/downloads/uClibc-0.9.32.tar.bz2 \
 SHA1=f8edc4ffcd9e8d1e8ae5348b9b879f5175010e67 \
-UNSTABLE=http://uclibc.org/downloads/uClibc-snapshot.tar.bz2 \
+ALT=http://uclibc.org/downloads/uClibc-snapshot.tar.bz2 \
 maybe_fork "download || dienow"
 
 # 2.17 was the last GPLv2 release of binutils
 
 URL=ftp://ftp.gnu.org/gnu/binutils/binutils-2.17.tar.bz2 \
 SHA1=a557686eef68362ea31a3aa41ce274e3eeae1ef0 \
-UNSTABLE=ftp://ftp.gnu.org/gnu/binutils/binutils-2.18.tar.bz2 \
+ALT=ftp://ftp.gnu.org/gnu/binutils/binutils-2.18.tar.bz2 \
 maybe_fork "download || dienow"
 
 # 4.2.1 was the last GPLv2 release of gcc
 
 URL=ftp://ftp.gnu.org/gnu/gcc/gcc-4.2.1/gcc-core-4.2.1.tar.bz2 \
 SHA1=43a138779e053a864bd16dfabcd3ffff04103213 \
-#UNSTABLE=ftp://ftp.gnu.org/gnu/gcc/gcc-4.4.1/gcc-core-4.4.1.tar.bz2 \
+#ALT=ftp://ftp.gnu.org/gnu/gcc/gcc-4.4.1/gcc-core-4.4.1.tar.bz2 \
 maybe_fork "download || dienow"
 
 # The g++ version must match gcc version.
 
 URL=http://ftp.gnu.org/gnu/gcc/gcc-4.2.1/gcc-g++-4.2.1.tar.bz2 \
 SHA1=8f3785bd0e092f563e14ecd26921cd04275496a6 \
-#UNSTABLE=http://ftp.gnu.org/gnu/gcc/gcc-4.4.1/gcc-g++-4.4.1.tar.bz2 \
+#ALT=http://ftp.gnu.org/gnu/gcc/gcc-4.4.1/gcc-g++-4.4.1.tar.bz2 \
 maybe_fork "download || dienow"
 
 # Building a native root filesystem requires linux and uClibc (above) plus
@@ -58,7 +58,7 @@
 
 URL=http://www.busybox.net/downloads/busybox-1.19.2.tar.bz2 \
 SHA1=6dedaa62af98a8541901a30c3e400ce9e077ee16 \
-#UNSTABLE=http://busybox.net/downloads/busybox-snapshot.tar.bz2 \
+#ALT=http://busybox.net/downloads/busybox-snapshot.tar.bz2 \
 maybe_fork "download || dienow"
 
 URL=ftp://ftp.gnu.org/gnu/make/make-3.81.tar.bz2 \
@@ -113,7 +113,7 @@
 # Create a MANIFEST file listing package versions.
 
 # This can optionally call source control systems (hg and svn) to get version
 # information for the build scripts and any USE_UNSTABLE packages.  These
 # are intentionally excluded from the new path setup by host-tools.sh, so
 # just in case we've already run that use $OLDPATH for this.
 
@@ -113,7 +113,7 @@
 
 # This can optionally call source control systems (hg and svn) to get version
-# information for the build scripts and any USE_UNSTABLE packages.  These
+# information for the build scripts and any USE_ALT packages.  These
 # are intentionally excluded from the new path setup by host-tools.sh, so
 # just in case we've already run that use $OLDPATH for this.
--- a/more/migrate-kernel.sh	Thu Oct 20 02:05:11 2011 -0500
+++ b/more/migrate-kernel.sh	Thu Oct 20 02:07:10 2011 -0500
@@ -1,6 +1,6 @@
 #!/bin/bash
 
 # Calculate new config for UNSTABLE kernel based on stable kernel config.
 # I.E. calculate miniconfig-alt-linux based on miniconfig-linux for a target.
 
 # Expand miniconfig with the old kernel, copy .config to new kernel, run
@@ -15,7 +15,7 @@
 
 # Expand config against current kernel
 
-USE_UNSTABLE=
+USE_ALT=
 
 getconfig linux > "$WORK/miniconfig-linux"
 
@@ -27,7 +27,7 @@
 
 cleanup
 
-USE_UNSTABLE=linux
+USE_ALT=linux
 
 setupfor linux
 
@@ -1,6 +1,6 @@
 #!/bin/bash
 
-# Calculate new config for UNSTABLE kernel based on stable kernel config.
+# Calculate new config for ALT kernel based on stable kernel config.
 # I.E. calculate miniconfig-alt-linux based on miniconfig-linux for a target.
 